@@ -14,6 +14,10 @@ describe 'basic cinder' do
       include openstack_integration::memcached
       include openstack_integration::keystone
       include openstack_integration::cinder
+
+      cinder_type { 'testvolumetype' :
+        properties => ['k=v', 'key1=val1', 'key2=<is> True']
+      }
       EOS
 
 
