@@ -56,10 +56,7 @@ describe 'cinder::db::sync' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({
-          :os_workers     => 8,
-          :concat_basedir => '/var/lib/puppet/concat'
-        }))
+        facts.merge(OSDefaults.get_facts())
       end
 
       it_behaves_like 'cinder-dbsync'
