@@ -29,6 +29,7 @@ describe 'cinder' do
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
           :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
@@ -44,27 +45,13 @@ describe 'cinder' do
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
-        )
-        is_expected.to contain_oslo__messaging__amqp('cinder_config').with(
-          :server_request_prefix => '<SERVICE DEFAULT>',
-          :broadcast_prefix      => '<SERVICE DEFAULT>',
-          :group_request_prefix  => '<SERVICE DEFAULT>',
-          :container_name        => '<SERVICE DEFAULT>',
-          :idle_timeout          => '<SERVICE DEFAULT>',
-          :trace                 => '<SERVICE DEFAULT>',
-          :ssl_ca_file           => '<SERVICE DEFAULT>',
-          :ssl_cert_file         => '<SERVICE DEFAULT>',
-          :ssl_key_file          => '<SERVICE DEFAULT>',
-          :sasl_mechanisms       => '<SERVICE DEFAULT>',
-          :sasl_config_dir       => '<SERVICE DEFAULT>',
-          :sasl_config_name      => '<SERVICE DEFAULT>',
-          :username              => '<SERVICE DEFAULT>',
-          :password              => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__notifications('cinder_config').with(
           :transport_url => '<SERVICE DEFAULT>',
           :driver        => '<SERVICE DEFAULT>',
-          :topics        => '<SERVICE DEFAULT>'
+          :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
         )
       }
 
@@ -112,11 +99,13 @@ describe 'cinder' do
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_qos_prefetch_count          => 0,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_enable_cancel_on_failover   => false,
         )
       end
 
@@ -124,11 +113,13 @@ describe 'cinder' do
         :heartbeat_timeout_threshold     => '60',
         :heartbeat_rate                  => '10',
         :heartbeat_in_pthread            => true,
+        :rabbit_qos_prefetch_count       => 0,
         :rabbit_quorum_queue             => true,
         :rabbit_transient_quorum_queue   => true,
         :rabbit_quorum_delivery_limit    => 3,
         :rabbit_quorum_max_memory_length => 5,
         :rabbit_quorum_max_memory_bytes  => 1073741824,
+        :enable_cancel_on_failover       => false,
       ) }
     end
 
@@ -206,29 +197,6 @@ describe 'cinder' do
       ) }
     end
 
-    context 'with amqp overrides' do
-      let :params do
-      {
-        :amqp_idle_timeout  => '60',
-        :amqp_trace         => true,
-        :amqp_ssl_ca_file   => '/path/to/ca.cert',
-        :amqp_ssl_cert_file => '/path/to/certfile',
-        :amqp_ssl_key_file  => '/path/to/key',
-        :amqp_username      => 'amqp_user',
-        :amqp_password      => 'password',
-      }
-      end
-
-      it { is_expected.to contain_oslo__messaging__amqp('cinder_config').with(
-        :idle_timeout  => '60',
-        :trace         => true,
-        :ssl_ca_file   => '/path/to/ca.cert',
-        :ssl_cert_file => '/path/to/certfile',
-        :username      => 'amqp_user',
-        :password      => 'password'
-      ) }
-    end
-
     context 'with image parameters ' do
       let :params do
         req_params.merge({
@@ -289,6 +257,7 @@ describe 'cinder' do
           :notification_transport_url => 'rabbit://notif_user:password@localhost:5673',
           :notification_driver        => 'messagingv2',
           :notification_topics        => 'test',
+          :notification_retry         => 10,
         })
       end
 
@@ -296,6 +265,7 @@ describe 'cinder' do
         :transport_url => params[:notification_transport_url],
         :driver        => params[:notification_driver],
         :topics        => params[:notification_topics],
+        :retry         => params[:notification_retry],
       )}
     end
 
