@@ -30,6 +30,13 @@ describe 'cinder::backend::dellemc_powermax' do
         is_expected.to contain_cinder_config("#{title}/powermax_srp").with_value('SRP_1')
         is_expected.to contain_cinder_config("#{title}/powermax_port_groups").with_value('[OS-ISCSI-PG]')
         is_expected.to contain_cinder_config("#{title}/backend_availability_zone").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/reserved_percentage").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/max_over_subscription_ratio").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/image_volume_cache_enabled").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/image_volume_cache_max_size_gb").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/image_volume_cache_max_count").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/rest_api_connect_timeout").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{title}/rest_api_read_timeout").with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_package('pywbem').with(
           :ensure => 'installed',
@@ -39,6 +46,24 @@ describe 'cinder::backend::dellemc_powermax' do
       end
     end
 
+    context 'with powermax_port_groups without bounds' do
+      before do
+        params.merge!(:powermax_port_groups => 'OS-ISCSI-PG')
+      end
+      it 'should add bounds' do
+        is_expected.to contain_cinder_config("#{title}/powermax_port_groups").with_value('[OS-ISCSI-PG]')
+      end
+    end
+
+    context 'with powermax_port_groups set by a list' do
+      before do
+        params.merge!(:powermax_port_groups => ['OS-ISCSI-PG1', 'OS-ISCSI-PG2'])
+      end
+      it 'should render a comma-separated list with bounds' do
+        is_expected.to contain_cinder_config("#{title}/powermax_port_groups").with_value('[OS-ISCSI-PG1,OS-ISCSI-PG2]')
+      end
+    end
+
     context 'with powermax_storage_protocol set to FC' do
       before do
         params.merge!(:powermax_storage_protocol => 'FC',)
@@ -57,19 +82,27 @@ describe 'cinder::backend::dellemc_powermax' do
       end
 
       it 'should raise an error' do
-        is_expected.to compile.and_raise_error(
-          /The cinder::backend::dellemc_powermax powermax_storage_protocol specified is not valid. It should be iSCSI or FC/
-        )
+        is_expected.to compile.and_raise_error(/Evaluation Error/)
       end
     end
 
-    context 'with custom backend_availability_zone' do
+    context 'with parameters' do
       before do
-        params.merge!(:backend_availability_zone => 'my_zone')
+        params.merge!({
+          :backend_availability_zone   => 'my_zone',
+          :reserved_percentage         => 10,
+          :max_over_subscription_ratio => 1.5,
+          :rest_api_connect_timeout    => 30,
+          :rest_api_read_timeout       => 31,
+        })
       end
 
-      it 'should configure the backend_availability_zone' do
+      it 'should configure the customized values' do
         is_expected.to contain_cinder_config("#{title}/backend_availability_zone").with_value('my_zone')
+        is_expected.to contain_cinder_config("#{title}/reserved_percentage").with_value(10)
+        is_expected.to contain_cinder_config("#{title}/max_over_subscription_ratio").with_value(1.5)
+        is_expected.to contain_cinder_config("#{title}/rest_api_connect_timeout").with_value(30)
+        is_expected.to contain_cinder_config("#{title}/rest_api_read_timeout").with_value(31)
       end
     end
 
