@@ -37,6 +37,11 @@ describe 'cinder::backend::emc_vnx' do
         is_expected.to contain_cinder_config('emc/storage_vnx_security_file_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('emc/naviseccli_path').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('emc/backend_availability_zone').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('emc/image_volume_cache_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('emc/image_volume_cache_max_size_gb').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('emc/image_volume_cache_max_count').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('emc/reserved_percentage').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('emc/max_over_subscription_ratio').with_value('<SERVICE DEFAULT>')
       }
     end
 
@@ -58,6 +63,11 @@ describe 'cinder::backend::emc_vnx' do
           :manage_volume_type               => true,
           :storage_protocol                 => 'fc',
           :backend_availability_zone        => 'my_zone',
+          :image_volume_cache_enabled       => true,
+          :image_volume_cache_max_size_gb   => 100,
+          :image_volume_cache_max_count     => 101,
+          :reserved_percentage              => 10,
+          :max_over_subscription_ratio      => 1.5,
         })
       end
 
@@ -76,6 +86,11 @@ describe 'cinder::backend::emc_vnx' do
         is_expected.to contain_cinder_config('emc/naviseccli_path').with_value(params[:naviseccli_path])
         is_expected.to contain_cinder_config('emc/storage_protocol').with_value(params[:storage_protocol])
         is_expected.to contain_cinder_config('emc/backend_availability_zone').with_value(params[:backend_availability_zone])
+        is_expected.to contain_cinder_config('emc/image_volume_cache_enabled').with_value(params[:image_volume_cache_enabled])
+        is_expected.to contain_cinder_config('emc/image_volume_cache_max_size_gb').with_value(params[:image_volume_cache_max_size_gb])
+        is_expected.to contain_cinder_config('emc/image_volume_cache_max_count').with_value(params[:image_volume_cache_max_count])
+        is_expected.to contain_cinder_config('emc/reserved_percentage').with_value(params[:reserved_percentage])
+        is_expected.to contain_cinder_config('emc/max_over_subscription_ratio').with_value(1.5)
       }
 
       it { is_expected.to contain_cinder_type('emc').with(
