@@ -5,7 +5,6 @@ describe 'cinder::backend::hpe3par_iscsi' do
 
   let :req_params do
     {
-      :backend_availability_zone => 'my_zone',
       :hpe3par_api_url           => 'https://172.0.0.2:8080/api/v1',
       :hpe3par_username          => '3paradm',
       :hpe3par_password          => 'password',
@@ -21,10 +20,15 @@ describe 'cinder::backend::hpe3par_iscsi' do
   end
 
   shared_examples 'cinder::backend::hpe3par_iscsi' do
-    context 'hpe3par_iscsi volume driver' do
+    context 'with default parameters' do
       it {
         is_expected.to contain_cinder_config('hpe3par_iscsi/volume_driver').with_value('cinder.volume.drivers.hpe.hpe_3par_iscsi.HPE3PARISCSIDriver')
-        is_expected.to contain_cinder_config('hpe3par_iscsi/backend_availability_zone').with_value('my_zone')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/backend_availability_zone').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/image_volume_cache_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/image_volume_cache_max_size_gb').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/image_volume_cache_max_count').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/reserved_percentage').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/max_over_subscription_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('hpe3par_iscsi/hpe3par_api_url').with_value('https://172.0.0.2:8080/api/v1')
         is_expected.to contain_cinder_config('hpe3par_iscsi/hpe3par_username').with_value('3paradm')
         is_expected.to contain_cinder_config('hpe3par_iscsi/hpe3par_password').with_value('password')
@@ -35,6 +39,21 @@ describe 'cinder::backend::hpe3par_iscsi' do
       }
     end
 
+    context 'with parameters' do
+      before :each do
+        params.merge!({
+          :backend_availability_zone   => 'my_zone',
+          :reserved_percentage         => 10,
+          :max_over_subscription_ratio => 1.5,
+        })
+      end
+      it {
+        is_expected.to contain_cinder_config('hpe3par_iscsi/backend_availability_zone').with_value('my_zone')
+        is_expected.to contain_cinder_config('hpe3par_iscsi/reserved_percentage').with_value(10)
+        is_expected.to contain_cinder_config('hpe3par_iscsi/max_over_subscription_ratio').with_value(1.5)
+      }
+    end
+
     context 'hpe3par_iscsi backend with additional configuration' do
       before :each do
         params.merge!( :extra_options => {'hpe3par_iscsi/param1' => {'value' => 'value1'}} )
