@@ -7,32 +7,50 @@ describe 'cinder::backend::iscsi' do
     context 'with default params' do
       it {
         is_expected.to contain_cinder_config('hippo/volume_backend_name').with_value('hippo')
+        is_expected.to contain_cinder_config('hippo/image_volume_cache_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hippo/image_volume_cache_max_size_gb').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hippo/image_volume_cache_max_count').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('hippo/backend_availability_zone').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hippo/reserved_percentage').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hippo/max_over_subscription_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('hippo/volume_driver').with_value('cinder.volume.drivers.lvm.LVMVolumeDriver')
         is_expected.to contain_cinder_config('hippo/target_ip_address').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('hippo/target_helper').with_value(platform_params[:target_helper])
         is_expected.to contain_cinder_config('hippo/volume_group').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('hippo/volumes_dir').with_value('/var/lib/cinder/volumes')
         is_expected.to contain_cinder_config('hippo/target_protocol').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('hippo/lvm_type').with_value('<SERVICE DEFAULT>')
       }
     end
 
     context 'with parameters' do
       let :params do
         {
-          :backend_availability_zone => 'nova',
-          :target_ip_address         => '192.0.2.1',
-          :volume_group              => 'volumegroup',
-          :volumes_dir               => '/etc/cinder/volumes',
-          :target_protocol           => 'iser'
+          :backend_availability_zone      => 'nova',
+          :image_volume_cache_enabled     => true,
+          :image_volume_cache_max_size_gb => 100,
+          :image_volume_cache_max_count   => 101,
+          :reserved_percentage            => 10,
+          :max_over_subscription_ratio    => 1.5,
+          :target_ip_address              => '192.0.2.1',
+          :volume_group                   => 'volumegroup',
+          :volumes_dir                    => '/etc/cinder/volumes',
+          :target_protocol                => 'iser',
+          :lvm_type                       => 'auto',
         }
       end
       it {
         is_expected.to contain_cinder_config('hippo/backend_availability_zone').with_value('nova')
+        is_expected.to contain_cinder_config('hippo/image_volume_cache_enabled').with_value(true)
+        is_expected.to contain_cinder_config('hippo/image_volume_cache_max_size_gb').with_value(100)
+        is_expected.to contain_cinder_config('hippo/image_volume_cache_max_count').with_value(101)
+        is_expected.to contain_cinder_config('hippo/reserved_percentage').with_value(10)
+        is_expected.to contain_cinder_config('hippo/max_over_subscription_ratio').with_value(1.5)
         is_expected.to contain_cinder_config('hippo/target_ip_address').with_value('192.0.2.1')
         is_expected.to contain_cinder_config('hippo/volume_group').with_value('volumegroup')
         is_expected.to contain_cinder_config('hippo/volumes_dir').with_value('/etc/cinder/volumes')
         is_expected.to contain_cinder_config('hippo/target_protocol').with_value('iser')
+        is_expected.to contain_cinder_config('hippo/lvm_type').with_value('auto')
       }
     end
 
