@@ -6,7 +6,6 @@ describe 'cinder::backend::netapp' do
   let :params do
     {
       :volume_backend_name          => 'netapp-cdot-nfs',
-      :backend_availability_zone    => 'my_zone',
       :netapp_login                 => 'netapp',
       :netapp_password              => 'password',
       :netapp_server_hostname       => '127.0.0.2',
@@ -17,21 +16,26 @@ describe 'cinder::backend::netapp' do
 
   let :default_params do
     {
-      :backend_availability_zone    => '<SERVICE DEFAULT>',
-      :netapp_server_port           => '<SERVICE DEFAULT>',
-      :netapp_size_multiplier       => '<SERVICE DEFAULT>',
-      :netapp_storage_family        => '<SERVICE DEFAULT>',
-      :netapp_storage_protocol      => 'nfs',
-      :netapp_transport_type        => '<SERVICE DEFAULT>',
-      :netapp_vserver               => '<SERVICE DEFAULT>',
-      :expiry_thres_minutes         => '<SERVICE DEFAULT>',
-      :thres_avl_size_perc_start    => '<SERVICE DEFAULT>',
-      :thres_avl_size_perc_stop     => '<SERVICE DEFAULT>',
-      :nfs_shares_config            => '/etc/cinder/shares.conf',
-      :netapp_copyoffload_tool_path => '<SERVICE DEFAULT>',
-      :nfs_mount_options            => '<SERVICE DEFAULT>',
-      :nas_secure_file_operations   => '<SERVICE DEFAULT>',
-      :nas_secure_file_permissions  => '<SERVICE DEFAULT>',
+      :backend_availability_zone      => '<SERVICE DEFAULT>',
+      :image_volume_cache_enabled     => '<SERVICE DEFAULT>',
+      :image_volume_cache_max_size_gb => '<SERVICE DEFAULT>',
+      :image_volume_cache_max_count   => '<SERVICE DEFAULT>',
+      :reserved_percentage            => '<SERVICE DEFAULT>',
+      :max_over_subscription_ratio    => '<SERVICE DEFAULT>',
+      :netapp_server_port             => '<SERVICE DEFAULT>',
+      :netapp_size_multiplier         => '<SERVICE DEFAULT>',
+      :netapp_storage_family          => '<SERVICE DEFAULT>',
+      :netapp_storage_protocol        => 'nfs',
+      :netapp_transport_type          => '<SERVICE DEFAULT>',
+      :netapp_vserver                 => '<SERVICE DEFAULT>',
+      :expiry_thres_minutes           => '<SERVICE DEFAULT>',
+      :thres_avl_size_perc_start      => '<SERVICE DEFAULT>',
+      :thres_avl_size_perc_stop       => '<SERVICE DEFAULT>',
+      :nfs_shares_config              => '/etc/cinder/shares.conf',
+      :netapp_copyoffload_tool_path   => '<SERVICE DEFAULT>',
+      :nfs_mount_options              => '<SERVICE DEFAULT>',
+      :nas_secure_file_operations     => '<SERVICE DEFAULT>',
+      :nas_secure_file_permissions    => '<SERVICE DEFAULT>',
     }
   end
 
@@ -55,14 +59,6 @@ describe 'cinder::backend::netapp' do
 
   shared_examples 'cinder::backend::netapp' do
     context 'with default parameters' do
-      before do
-        params = {}
-      end
-
-      it_behaves_like 'netapp volume driver'
-    end
-
-    context 'with provided parameters' do
       it_behaves_like 'netapp volume driver'
     end
 
@@ -79,9 +75,9 @@ describe 'cinder::backend::netapp' do
         params.merge!( :manage_volume_type => true )
       end
 
-      it { is_expected.to contain_cinder_type('netapp').with(
+      it { is_expected.to contain_cinder_type('netapp-cdot-nfs').with(
         :ensure     => 'present',
-        :properties => ['volume_backend_name=netapp']
+        :properties => ['volume_backend_name=netapp-cdot-nfs']
       )}
     end
 
