@@ -25,6 +25,9 @@ describe 'cinder::backend::quobyte' do
       is_expected.to contain_cinder_config('myquobyte/quobyte_qcow2_volumes').with_value(false)
       is_expected.to contain_cinder_config('myquobyte/quobyte_sparsed_volumes').with_value(true)
       is_expected.to contain_cinder_config('myquobyte/backend_availability_zone').with_value('my_zone')
+      is_expected.to contain_cinder_config('myquobyte/image_volume_cache_enabled').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_cinder_config('myquobyte/image_volume_cache_max_size_gb').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_cinder_config('myquobyte/image_volume_cache_max_count').with_value('<SERVICE DEFAULT>')
     }
 
     context 'quobyte backend with cinder type' do
